@@ -1,7 +1,9 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 """Simple test for keypad on I2C RGB character LCD Shield or Pi Plate kits"""
 import time
 import board
-import busio
 import adafruit_character_lcd.character_lcd_rgb_i2c as character_lcd
 
 # Modify this if you have a different sized Character LCD
@@ -9,7 +11,8 @@ lcd_columns = 16
 lcd_rows = 2
 
 # Initialise I2C bus.
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 
 # Initialise the LCD class
 lcd = character_lcd.Character_LCD_RGB_I2C(i2c, lcd_columns, lcd_rows)
